@@ -83,7 +83,7 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
         LOGGER.warning('We don\'t seem to be running on an MDC!')
 
 
-def client_is_unreachable(client):
+def client_ping_response(client):
     """Ping the client.
     True == client is reachable
     False == client is not
@@ -189,7 +189,7 @@ def get_stats_from_client(client):
     io_data = None
     http_response = None
 
-    if not client_is_unreachable(client):
+    if client_ping_response(client) == 0:
         try:
             LOGGER.info('Requesting stats from %s', client.host_name)
             http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
